@@ -17,12 +17,15 @@ def status():
     click.echo(gf.status())
 
 @cli.command()
-@click.option('-url', type=str, help='Paste your link of the repo')
+@click.option('-url', type=str, help='Paste your link of the repo',required=False)
 @click.option('-m',type=str,help = "Commit message ")
 @click.option('-b',type=str, help ="Branch name for checkout")
-def pushbranch(url,m,b):
-    click.echo(gf.push_branch(url,m,b))
+def pushbranch(m,b,**url):
+    click.echo(gf.push_branch(m,b,**url))
 
 @cli.command()
 def remote():
-    click.echo(gf.remote())
\ No newline at end of file
+    click.echo(gf.remote())
+
+if __name__ == '__main__':
+    cli()
\ No newline at end of file
